@@ -1,6 +1,6 @@
 # core dependencies
 import time
-from src.abba_python.abba_python import start_imagej
+from abba_python import start_imagej
 
 # in order to wait for a jvm shutdown
 import jpype
